@@ -49,7 +49,7 @@ class OpenProvider(object):
         # Set up the API client
         self.session = requests.Session()
         self.session.verify = True
-        self.session.headers['User-Agent'] = 'openprovider.py/0.6.0'
+        self.session.headers['User-Agent'] = 'openprovider.py/0.7.0'
 
         # Initialize and add all modules.
         for old_name, module in MODULE_MAPPING.items():
@@ -78,11 +78,11 @@ class OpenProvider(object):
             method='c14n'
         )
 
-        apiresponse = self.session.post(self.url, data=apirequest)
-
-        # OpenProvider doesn't use codes, so this only catches 5xx errors
-        if apiresponse.status_code != requests.codes.ok:
-            raise ServiceUnavailable()
+        try:
+            apiresponse = self.session.post(self.url, data=apirequest)
+            apiresponse.raise_for_status()
+        except requests.RequestException as e:
+            raise ServiceUnavailable(str(e))
 
         tree = lxml.objectify.fromstring(apiresponse.content)
 
@@ -92,7 +92,7 @@ class OpenProvider(object):
             klass = from_code(tree.reply.code)
             desc = tree.reply.desc
             code = tree.reply.code
-            data = tree.reply.data
+            data = getattr(tree.reply, 'data', '')
             raise klass("{0} ({1}) {2}".format(desc, code, data))
 
 
