@@ -105,7 +105,8 @@ class DomainModule(common.Module):
     def modify_domain_request(self, domain, owner_handle=None, admin_handle=None, tech_handle=None,
             billing_handle=None, reseller_handle=None, ns_group=None, ns_template_name=None,
             name_servers=None, use_domicile=False, promo_code=None, autorenew=None, comments=None,
-            dnssec_keys=None, application_mode=None, is_private_whois_enabled=None):
+            dnssec_keys=None, application_mode=None, is_private_whois_enabled=None,
+            is_locked=None):
 
         request = E.modifyDomainRequest(
                 _domain(domain),
@@ -124,11 +125,17 @@ class DomainModule(common.Module):
                 OE('dnssecKeys', dnssec_keys, transform=_dnssec_keys),
                 OE('applicationMode', application_mode),
                 OE('isPrivateWhoisEnabled', is_private_whois_enabled, transform=int),
+                OE('isLocked', is_locked, transform=int),
         )
-        self.request(request)
+        response = self.request(request)
+        return response.as_model(Model)
 
     def retrieve_domain_request(self, domain, additional_data=False, registry_details=False):
-        request = E.retrieveDomainRequest(_domain(domain))
+        request = E.retrieveDomainRequest(
+                _domain(domain),
+                E.withAdditionalData(int(additional_data)),
+                E.withRegistryDetails(int(registry_details)),
+        )
         response = self.request(request)
         return response.as_model(DomainDetails)
 
